var class_ogre_1_1_auto_param_data_source =
[
    [ "AutoParamDataSource", "class_ogre_1_1_auto_param_data_source.html#aac2d60d46041f69d6727c192ad7b9c48", null ],
    [ "setCurrentRenderable", "class_ogre_1_1_auto_param_data_source.html#a012ceb6b159c4d81e9b63170f235e63f", null ],
    [ "setWorldMatrices", "class_ogre_1_1_auto_param_data_source.html#ae65d20f572488b5bff84f095b0850783", null ],
    [ "setCurrentCamera", "class_ogre_1_1_auto_param_data_source.html#a0c71d0f089723307c8329f28f0ddc228", null ],
    [ "setCameraArray", "class_ogre_1_1_auto_param_data_source.html#a449463ded816f13ccde02a794d5aeff1", null ],
    [ "setCurrentLightList", "class_ogre_1_1_auto_param_data_source.html#afac03642ad3286b4f7f7afca616b4acb", null ],
    [ "setTextureProjector", "class_ogre_1_1_auto_param_data_source.html#a0191611c98b4a46328b5610a53a77781", null ],
    [ "setCurrentRenderTarget", "class_ogre_1_1_auto_param_data_source.html#a8c59386216c2a61d34ce48195cc5a319", null ],
    [ "setCurrentViewport", "class_ogre_1_1_auto_param_data_source.html#acf1d6437569d11c76ad45870973392a9", null ],
    [ "setShadowDirLightExtrusionDistance", "class_ogre_1_1_auto_param_data_source.html#a6717ec5326ce4b1f23a3b12a918405ff", null ],
    [ "setShadowPointLightExtrusionDistance", "class_ogre_1_1_auto_param_data_source.html#a39e01d074d67cb9b85974eb6cb266ce7", null ],
    [ "setMainCamBoundsInfo", "class_ogre_1_1_auto_param_data_source.html#a8155db39fe05dbae91ce7d477e8df2c7", null ],
    [ "setCurrentSceneManager", "class_ogre_1_1_auto_param_data_source.html#a3b7c0951247ef96473986260d734f280", null ],
    [ "setCurrentPass", "class_ogre_1_1_auto_param_data_source.html#a8cb7a3811435381b3f84361edcff7fd7", null ],
    [ "getCurrentCamera", "class_ogre_1_1_auto_param_data_source.html#a7a08412b2e98f75cf5b960217e2ad207", null ],
    [ "getWorldMatrix", "class_ogre_1_1_auto_param_data_source.html#a6f264e09765f1837a78138dc7c9cea27", null ],
    [ "getBoneMatrixArray", "class_ogre_1_1_auto_param_data_source.html#a83f8a35af9d59e1f3fa27131d0353814", null ],
    [ "getWorldMatrixArray", "class_ogre_1_1_auto_param_data_source.html#a8aff42e92e49e68078581ab722f10426", null ],
    [ "getBoneMatrixCount", "class_ogre_1_1_auto_param_data_source.html#a3abc7f04e2b4891e4a5e831f8912dcf0", null ],
    [ "getWorldMatrixCount", "class_ogre_1_1_auto_param_data_source.html#a8ae6715c657ad1bf2483102aec8f9281", null ],
    [ "getViewMatrix", "class_ogre_1_1_auto_param_data_source.html#a8402e87412505edf845510081ab0008e", null ],
    [ "getViewMatrix", "class_ogre_1_1_auto_param_data_source.html#a6b7ddc68ac1e1bda0dce281ccb5ce2a1", null ],
    [ "getViewProjectionMatrix", "class_ogre_1_1_auto_param_data_source.html#a20da1d44783a1f3454bf34671aed328e", null ],
    [ "getProjectionMatrix", "class_ogre_1_1_auto_param_data_source.html#a0aed6b631a2965082888a298af83ca52", null ],
    [ "getProjectionMatrix", "class_ogre_1_1_auto_param_data_source.html#ab6191abc4f9811318ac2fb166d17471b", null ],
    [ "getWorldViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#a9b3d1e3e28114671174b90b54bf1de76", null ],
    [ "getWorldViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#a2b176605da2fc03fe2c62e52b252d063", null ],
    [ "getWorldViewMatrix", "class_ogre_1_1_auto_param_data_source.html#aad2fb1df270848f191ee987d7174dc91", null ],
    [ "getInverseWorldMatrix", "class_ogre_1_1_auto_param_data_source.html#a389304ad714617d6fb1c56d6302bd8e4", null ],
    [ "getInverseWorldViewMatrix", "class_ogre_1_1_auto_param_data_source.html#a547eeceff510f5816ada49077e336a22", null ],
    [ "getInverseViewMatrix", "class_ogre_1_1_auto_param_data_source.html#a586d4ef66401acf2e61000e687ea10fa", null ],
    [ "getInverseTransposeWorldMatrix", "class_ogre_1_1_auto_param_data_source.html#ab880bcfbc01d4625049dcd413ab00635", null ],
    [ "getInverseTransposeWorldViewMatrix", "class_ogre_1_1_auto_param_data_source.html#aaee6b7dc6da28a9855f08769a4ff7ff9", null ],
    [ "getCameraPosition", "class_ogre_1_1_auto_param_data_source.html#aa97ab79b65e3a06040b4f2c88e8e2197", null ],
    [ "getCameraPositionObjectSpace", "class_ogre_1_1_auto_param_data_source.html#a314f0d8086c271ebfe3226262897d0a6", null ],
    [ "getCameraRelativePosition", "class_ogre_1_1_auto_param_data_source.html#a983be0d2b9d732f114aa79ab2f779324", null ],
    [ "getLodCameraPosition", "class_ogre_1_1_auto_param_data_source.html#a930a974569b1a8d261cb979072ba3459", null ],
    [ "getLodCameraPositionObjectSpace", "class_ogre_1_1_auto_param_data_source.html#ad6e0eb1261856ceb9ed2630269968ec7", null ],
    [ "hasLightList", "class_ogre_1_1_auto_param_data_source.html#a31c547d8c3a9d05977dfc931c96ee057", null ],
    [ "getLightNumber", "class_ogre_1_1_auto_param_data_source.html#ae17cb66127fbb4cbc661c6772ad12c36", null ],
    [ "getLightCount", "class_ogre_1_1_auto_param_data_source.html#ac9540c2857991ff352b278a45c37125f", null ],
    [ "getLightCastsShadows", "class_ogre_1_1_auto_param_data_source.html#adc653a9e44ddfe33bea94542c84ab7c0", null ],
    [ "getLightDiffuseColour", "class_ogre_1_1_auto_param_data_source.html#a225d95b4c72a6e2faf7390444c0db618", null ],
    [ "getLightSpecularColour", "class_ogre_1_1_auto_param_data_source.html#a871c57f7667f6093dc453848a204aaaf", null ],
    [ "getLightDiffuseColourWithPower", "class_ogre_1_1_auto_param_data_source.html#abd243535ede1b318faf0750b07e28ed0", null ],
    [ "getLightSpecularColourWithPower", "class_ogre_1_1_auto_param_data_source.html#aa8d499add7fede573d2f45d9987ef2d3", null ],
    [ "getLightPosition", "class_ogre_1_1_auto_param_data_source.html#a6017b03e207210c338b6e04b7464632e", null ],
    [ "getLightAs4DVector", "class_ogre_1_1_auto_param_data_source.html#aa4a210bf87f325fa333f3d41ad448fbe", null ],
    [ "getLightDirection", "class_ogre_1_1_auto_param_data_source.html#a3ee1cf2b68ec6e12934028ad15ee4891", null ],
    [ "getLightPowerScale", "class_ogre_1_1_auto_param_data_source.html#a8841597c2eab462d35a642940a7454e5", null ],
    [ "getLightAttenuation", "class_ogre_1_1_auto_param_data_source.html#a43d3fdf2d35c4b3136e57abc837bdf5a", null ],
    [ "getSpotlightParams", "class_ogre_1_1_auto_param_data_source.html#a68688727cf79af15e83250e51d74904d", null ],
    [ "setAmbientLightColour", "class_ogre_1_1_auto_param_data_source.html#aa8f0af50eb6150b7a06ef6213aa0cb3a", null ],
    [ "getAmbientLightColour", "class_ogre_1_1_auto_param_data_source.html#abe6cdf9244a6bef0f3b32f2a7fbd4727", null ],
    [ "getSurfaceAmbientColour", "class_ogre_1_1_auto_param_data_source.html#a9523b96e82996da94e60931d26f4073c", null ],
    [ "getSurfaceDiffuseColour", "class_ogre_1_1_auto_param_data_source.html#a99862cfda02fa441874bc788619807fa", null ],
    [ "getSurfaceSpecularColour", "class_ogre_1_1_auto_param_data_source.html#ac5c34e0a5a8220f07a110fb8a93c2ecb", null ],
    [ "getSurfaceEmissiveColour", "class_ogre_1_1_auto_param_data_source.html#a3b762d0704ce11a8e5a04a7f98962312", null ],
    [ "getSurfaceShininess", "class_ogre_1_1_auto_param_data_source.html#a8407761823628a8183cbf1d0e937d729", null ],
    [ "getSurfaceAlphaRejectionValue", "class_ogre_1_1_auto_param_data_source.html#a94b6c375f34abf6b3e2affc62d70fad6", null ],
    [ "getDerivedAmbientLightColour", "class_ogre_1_1_auto_param_data_source.html#aa393a28288496ad73531b972891528f6", null ],
    [ "getDerivedSceneColour", "class_ogre_1_1_auto_param_data_source.html#a277b593c791b45b0521858d28374906c", null ],
    [ "setFog", "class_ogre_1_1_auto_param_data_source.html#afbc4da8d67e1c222326656fcdf73517c", null ],
    [ "getFogColour", "class_ogre_1_1_auto_param_data_source.html#ae378fd16ab162c4fc808173e7b08c192", null ],
    [ "getFogParams", "class_ogre_1_1_auto_param_data_source.html#a804416e7c07fbaf588ca4d4774034ccf", null ],
    [ "setPointParameters", "class_ogre_1_1_auto_param_data_source.html#a1f8ec4ab36fcfc2f84347db42d275e81", null ],
    [ "getPointParams", "class_ogre_1_1_auto_param_data_source.html#a6c2669b838f1667f67181cdbd9cb0fd0", null ],
    [ "getTextureViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#a40890ec8e898d76c7c114624061031a2", null ],
    [ "getTextureWorldViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#a464c97ee2e5b202b47c2eab43f8beaac", null ],
    [ "getSpotlightViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#a130e70c2cfed4b5b715c96e04d2087f3", null ],
    [ "getSpotlightWorldViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#a78cb74380cd05779a1a4b37920a61141", null ],
    [ "getTextureTransformMatrix", "class_ogre_1_1_auto_param_data_source.html#aca1a02daa6c7bcdc2fedccddf9df69be", null ],
    [ "getCurrentRenderTarget", "class_ogre_1_1_auto_param_data_source.html#a6ed5785f837429de0c61ad97b47d992b", null ],
    [ "getCurrentRenderable", "class_ogre_1_1_auto_param_data_source.html#adc48dadfd30c9e187c66daee66c1ebf2", null ],
    [ "getCurrentPass", "class_ogre_1_1_auto_param_data_source.html#a65f9d1c169a20621c824e704d653aea4", null ],
    [ "getTextureSize", "class_ogre_1_1_auto_param_data_source.html#a9ca27385ae9cdb5f6330ffbb9430dbba", null ],
    [ "getInverseTextureSize", "class_ogre_1_1_auto_param_data_source.html#ae45919ce72d00ea4930bd7a738f3647e", null ],
    [ "getPackedTextureSize", "class_ogre_1_1_auto_param_data_source.html#a65869fa5a6e2073396fa427be43fa2b1", null ],
    [ "getShadowExtrusionDistance", "class_ogre_1_1_auto_param_data_source.html#a666f1089d83b0da3d223157ef72390b9", null ],
    [ "getSceneDepthRange", "class_ogre_1_1_auto_param_data_source.html#ad37c94d86c7128ebc9e1f000eb3ef332", null ],
    [ "getShadowSceneDepthRange", "class_ogre_1_1_auto_param_data_source.html#ace31465a839948a9c08f67049e2059a1", null ],
    [ "setShadowColour", "class_ogre_1_1_auto_param_data_source.html#a7da9209eabc44a6a28a3bbe9d788a425", null ],
    [ "getShadowColour", "class_ogre_1_1_auto_param_data_source.html#a48aadefcfa972ace170d3415b3dcfa92", null ],
    [ "getInverseViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#af881e8166923f6aa80c5f73c9d207da2", null ],
    [ "getInverseTransposeViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#a0246b52c319c20e0f95f9f385f188180", null ],
    [ "getTransposeViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#ae7f22106e1254326ddaeda590de483de", null ],
    [ "getTransposeViewMatrix", "class_ogre_1_1_auto_param_data_source.html#a5f9141696f323d6d0a5ed77077630531", null ],
    [ "getInverseTransposeViewMatrix", "class_ogre_1_1_auto_param_data_source.html#a650c71c0ad70c44d23b4d33092f9f33d", null ],
    [ "getTransposeProjectionMatrix", "class_ogre_1_1_auto_param_data_source.html#a8904ec684a6d7adbce4c887976f1e283", null ],
    [ "getInverseProjectionMatrix", "class_ogre_1_1_auto_param_data_source.html#a70e9f9f02e02daf656c4bebfc5ff4c0f", null ],
    [ "getInverseTransposeProjectionMatrix", "class_ogre_1_1_auto_param_data_source.html#ad98976d0ddb21ac3c156fa3cf2b954ff", null ],
    [ "getTransposeWorldViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#a5f9bc5e389b70dbb8832eb9e6084dcf1", null ],
    [ "getInverseWorldViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#a3d5d2e191b4f0762a595f760b106502d", null ],
    [ "getInverseTransposeWorldViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#a40d734fec257ade58e76338212976588", null ],
    [ "getTransposeWorldViewMatrix", "class_ogre_1_1_auto_param_data_source.html#ad1dd231941ab67203eb860b74ea0ed31", null ],
    [ "getTransposeWorldMatrix", "class_ogre_1_1_auto_param_data_source.html#a13aa8e5ee2fd8a583283ae8d13d430eb", null ],
    [ "getTime", "class_ogre_1_1_auto_param_data_source.html#ab7c646bc7022fdc761319ec682227c18", null ],
    [ "getTime_0_X", "class_ogre_1_1_auto_param_data_source.html#abecccf8eb4fa1df0d4d301a3c2fa74bd", null ],
    [ "getCosTime_0_X", "class_ogre_1_1_auto_param_data_source.html#a0bf12c724c3dba7d91825b540c1beb63", null ],
    [ "getSinTime_0_X", "class_ogre_1_1_auto_param_data_source.html#a7d7446b7b28f317c1351fbb81894113c", null ],
    [ "getTanTime_0_X", "class_ogre_1_1_auto_param_data_source.html#a827e747d0cb30e28b5d6e52706e6c64d", null ],
    [ "getTime_0_X_packed", "class_ogre_1_1_auto_param_data_source.html#a49030641da8363e218355c7050161b63", null ],
    [ "getTime_0_1", "class_ogre_1_1_auto_param_data_source.html#aaccd003a6c19e21199020afa408b7a8b", null ],
    [ "getCosTime_0_1", "class_ogre_1_1_auto_param_data_source.html#a0e8a458333be1ea5c38445a9311adab3", null ],
    [ "getSinTime_0_1", "class_ogre_1_1_auto_param_data_source.html#af6885995084c9c3721dd9f6509272792", null ],
    [ "getTanTime_0_1", "class_ogre_1_1_auto_param_data_source.html#a7fe74b5115a61d6417bc2ceaafa1da08", null ],
    [ "getTime_0_1_packed", "class_ogre_1_1_auto_param_data_source.html#a9e55568c8aac9a721df96a32f9a1dfe0", null ],
    [ "getTime_0_2Pi", "class_ogre_1_1_auto_param_data_source.html#a8538421ec4e7e1b4e512ae7dddee5b90", null ],
    [ "getCosTime_0_2Pi", "class_ogre_1_1_auto_param_data_source.html#a4bc5fc520f9100a83a9d5bff3cfbad0a", null ],
    [ "getSinTime_0_2Pi", "class_ogre_1_1_auto_param_data_source.html#a6c2f4f32c3acde7733a5873cc6031445", null ],
    [ "getTanTime_0_2Pi", "class_ogre_1_1_auto_param_data_source.html#ae062455476f67ebfeb7f3fddba6adf8c", null ],
    [ "getTime_0_2Pi_packed", "class_ogre_1_1_auto_param_data_source.html#ad45072a11bd8a0d445345df02816799c", null ],
    [ "getFrameTime", "class_ogre_1_1_auto_param_data_source.html#a7ac99bd13593347106944988fe704de6", null ],
    [ "getFPS", "class_ogre_1_1_auto_param_data_source.html#a1b250c601f5c295a56cb9a3851b9f131", null ],
    [ "getViewportWidth", "class_ogre_1_1_auto_param_data_source.html#a311123590ba6ac6c5a787cf02455c7ae", null ],
    [ "getViewportHeight", "class_ogre_1_1_auto_param_data_source.html#ae7d883b808fdccae70db7f300da087fa", null ],
    [ "getInverseViewportWidth", "class_ogre_1_1_auto_param_data_source.html#acfed73d5c9e03efbe4d591980ac4774c", null ],
    [ "getInverseViewportHeight", "class_ogre_1_1_auto_param_data_source.html#aca4cbec02abcd89910cd8d8aa85bcd81", null ],
    [ "getViewDirection", "class_ogre_1_1_auto_param_data_source.html#aac4a2228168a324f4d8557f8a1e98d9a", null ],
    [ "getViewSideVector", "class_ogre_1_1_auto_param_data_source.html#aeb270c2b5ee674a730006d99bc56e337", null ],
    [ "getViewUpVector", "class_ogre_1_1_auto_param_data_source.html#ad03d4cb164534097d0f1454b0f8c8244", null ],
    [ "getFOV", "class_ogre_1_1_auto_param_data_source.html#a30fd5244735122fac14ee28d93f45bdb", null ],
    [ "getNearClipDistance", "class_ogre_1_1_auto_param_data_source.html#a6b742632035316c548495bc418d710bf", null ],
    [ "getFarClipDistance", "class_ogre_1_1_auto_param_data_source.html#addc840cce714751d540ee2bb920edadc", null ],
    [ "getPassNumber", "class_ogre_1_1_auto_param_data_source.html#afc777a9773bae73e390e3674ccf34ca7", null ],
    [ "getMaterialLodIndex", "class_ogre_1_1_auto_param_data_source.html#a86458c2d1090f3166f81108681d5c985", null ],
    [ "setPassNumber", "class_ogre_1_1_auto_param_data_source.html#ae8a89e12bc5d045403ab11659f56118f", null ],
    [ "incPassNumber", "class_ogre_1_1_auto_param_data_source.html#abef8a2c10bbd789eb6c69f79c1356be8", null ],
    [ "updateLightCustomGpuParameter", "class_ogre_1_1_auto_param_data_source.html#aab98cdc91cf17d2651f89c6b30f37786", null ]
];